@@ -1,5 +1,5 @@
 /***************************************************************************
- *   2007-2022 by Peter Semiletov                                          *
+ *   2007-2023 by Peter Semiletov                                          *
  *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -53,13 +53,11 @@ code from qwriter:
 #include <QMimeData>
 #include <QFile>
 #include <QMessageBox>
-
 #include <QTimer>
 
 #include "document.h"
 #include "utils.h"
 #include "gui_utils.h"
-//#include "textproc.h"
 
 #include "pugixml.hpp"
 
@@ -356,7 +354,6 @@ public:
   CSyntaxHighlighterQRegExp *hl;
   int darker_val;
 
-
   bool for_each (pugi::xml_node& node);
 };
 
@@ -506,14 +503,12 @@ void CSyntaxHighlighterQRegExp::load_from_xml_pugi (const QString &fname)
 
   int darker_val = settings->value ("darker_val", 100).toInt();
 
-
   pugi::xml_document doc;
   pugi::xml_parse_result result = doc.load_buffer (temp.utf16(),
                                                    temp.size() * 2,
                                                    pugi::parse_default,
                                                    pugi::encoding_utf16);
 
-
    //pugi::xml_parse_result result = doc.load_buffer (temp.toUtf8().data(),
      //                                               temp.toUtf8().size());
 
@@ -525,7 +520,6 @@ void CSyntaxHighlighterQRegExp::load_from_xml_pugi (const QString &fname)
    walker.hl = this;
 
    doc.traverse (walker);
-
 }
 
 #endif
@@ -698,7 +692,6 @@ bool CXMLHL_walker::for_each (pugi::xml_node &node)
 
   if (tag_name == "item")
      {
-
       pugi::xml_attribute attr = node.attribute ("type");
       QString attr_type = attr.as_string();
       attr = node.attribute ("name");
@@ -707,7 +700,6 @@ bool CXMLHL_walker::for_each (pugi::xml_node &node)
       if (attr_name == "options")
          {
 //          attr = node.attribute ("casecare");
-
           QString s_casecare = node.attribute ("casecare").as_string();
           if (! s_casecare.isEmpty())
              if (s_casecare == "0" || s_casecare == "false")
@@ -1112,6 +1104,7 @@ void CDocument::keyPressEvent (QKeyEvent *event)
       event->accept();
       return;
      }
+/*
 
 #if QT_VERSION >= 0x050000
 
@@ -1139,6 +1132,30 @@ void CDocument::keyPressEvent (QKeyEvent *event)
       return;
      }
 #endif
+*/
+
+
+  if (event->key() == Qt::Key_C && (event->modifiers().testFlag(Qt::ControlModifier)))
+     {
+      ed_copy();
+      event->accept();
+      return;
+     }
+
+
+  if (event->key() == Qt::Key_X && (event->modifiers().testFlag(Qt::ControlModifier)))
+     {
+      ed_cut();
+      event->accept();
+      return;
+     }
+
+  if (event->key() == Qt::Key_V && (event->modifiers().testFlag(Qt::ControlModifier)))
+     {
+      ed_paste();
+      event->accept();
+      return;
+     }
 
 
   QPlainTextEdit::keyPressEvent (event);
@@ -1181,6 +1198,32 @@ void CDocument::wheelEvent (QWheelEvent *e)
 }
 
 
+void CDocument::contextMenuEvent (QContextMenuEvent *event)
+{
+  QMenu *menu = new QMenu (this);
+
+  QAction *a = menu->addAction (tr("Copy"));
+  connect (a, SIGNAL(triggered()), this, SLOT(ed_copy()));
+
+  a = menu->addAction (tr("Cut"));
+  connect (a, SIGNAL(triggered()), this, SLOT(ed_cut()));
+
+  a = menu->addAction (tr("Paste"));
+  connect (a, SIGNAL(triggered()), this, SLOT(ed_paste()));
+
+  menu->addSeparator();
+
+  a = menu->addAction (tr("Undo"));
+  connect (a, SIGNAL(triggered()), this, SLOT(undo()));
+
+  a = menu->addAction (tr("Redo"));
+  connect (a, SIGNAL(triggered()), this, SLOT(redo()));
+
+  menu->exec(event->globalPos());
+  delete menu;
+}
+
+
 CDocument::CDocument (CDox *hldr, QWidget *parent): QPlainTextEdit (parent)
 {
   holder = hldr;
@@ -1238,6 +1281,15 @@ CDocument::CDocument (CDox *hldr, QWidget *parent): QPlainTextEdit (parent)
   tab_page = holder->tab_widget->widget (tab_index);
 
 
+  //QAction *actCopy;
+//  QAction *actCut;
+  //QAction *actPaste;
+
+  //actCopy = new QAction (tr("Copy"), this);
+  //connect (actCopy, SIGNAL(triggered()), this, SLOT(ed_copy()));
+
+//   setContextMenuPolicy (Qt::PreventContextMenu);
+
 /*
   set dots color, put to hl init
  spaceFormat = QtGui.QTextCharFormat()
@@ -1303,11 +1355,81 @@ void CDocument::put (const QString &value)
 }
 
 
+void CDocument::ed_copy()
+{
+  if (! has_selection())
+     return;
+
+  QString t = get();
+
+#if defined(Q_OS_UNIX)
+    t = t.replace (QChar::ParagraphSeparator, "\n");
+#endif
+
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+    t = t.replace (QChar::ParagraphSeparator, "\r\n");
+#endif
+
+  QClipboard *clipboard = QApplication::clipboard();
+
+  clipboard->setText (t);
+}
+
+
+void CDocument::ed_cut()
+{
+  if (! has_selection())
+     return;
+
+  QString t = get();
+
+#if defined(Q_OS_UNIX)
+  t = t.replace (QChar::ParagraphSeparator, "\n");
+#endif
+
+#if defined(Q_OS_WIN) || defined(Q_OS_OS2)
+  t = t.replace (QChar::ParagraphSeparator, "\r\n");
+#endif
+
+  QClipboard *clipboard = QApplication::clipboard();
+
+  clipboard->setText (t);
+
+  textCursor().insertText ("");
+}
+
+
+void CDocument::ed_paste()
+{
+  QClipboard *clipboard = QApplication::clipboard();
+  textCursor().insertText (clipboard->text());
+}
+
+
+bool CDocument::has_selection()
+{
+  return textCursor().hasSelection();
+}
+
+/*
+QMenu* CDocument::createStandardContextMenu()
+{
+  QMenu *m = new QMenu();
+
+  m->addAction (actCopy);
+
+  return m;
+}
+*/
+
+
 bool CDocument::file_open (const QString &fileName, const QString &codec)
 {
+  //qDebug() << "CDocument::file_open " << fileName;
+
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
 
-//  qDebug() << "tio->metaObject()->className()" << tio->metaObject()->className();
+  //qDebug() << "tio->metaObject()->className()" << tio->metaObject()->className();
 
   if (! tio)
       return false;
@@ -2540,6 +2662,7 @@ CDocument* CDox::open_file (const QString &fileName, const QString &codec)
       return td;
      }
 
+
   CDocument *d = get_document_by_fname (fileName);
   if (d)
      {
@@ -2548,6 +2671,7 @@ CDocument* CDox::open_file (const QString &fileName, const QString &codec)
       return d;
      }
 
+
 //else truly create the new doc
   d = create_new();
   d->file_open (fileName, codec);
