@@ -33,7 +33,7 @@ bool has_css_file (const QString &path)
 
   for (int i = 0; i < l.size(); i++)
       {
-       if (l.at(i).endsWith(".css"))
+       if (l.at(i).endsWith(".css", Qt::CaseInsensitive))
            return true;
       }
 
@@ -152,12 +152,12 @@ QString file_get_ext (const QString &file_name)
   if (file_name.isEmpty())
       return QString();
 
-/*  int i = file_name.lastIndexOf (".");
+ /* int i = file_name.lastIndexOf (".");
   if (i == -1)
       return QString();
 
-  return file_name.mid (i + 1).toLower();*/
-
+  return file_name.mid (i + 1).toLower();
+*/
   QFileInfo fi (file_name);
   return fi.completeSuffix();
 }
@@ -182,9 +182,13 @@ bool qstring_save (const QString &fileName, const QString &data, const char *enc
       return false;
 
   QTextCodec *codec = QTextCodec::codecForName (enc);
-  QByteArray ba = codec->fromUnicode(data);
+  if (! codec)
+     return false;
 
-  file.write(ba);
+
+  QByteArray ba = codec->fromUnicode (data);
+
+  file.write (ba);
   file.close();
 
   return true;
@@ -202,11 +206,14 @@ QString qstring_load (const QString &fileName, const char *enc)
       return QString();
 
   QByteArray ba = file.readAll();
-  QTextCodec *codec = QTextCodec::codecForName(enc);
+  QTextCodec *codec = QTextCodec::codecForName (enc);
+
+  if (! codec)
+     return QString();
 
   file.close();
 
-  return codec->toUnicode(ba);
+  return codec->toUnicode (ba);
 }
 
 
@@ -354,7 +361,7 @@ void hash_save_keyval (const QString &fname, const QHash <QString, QString> &h)
   while (i != h.constEnd())
         {
          l+= (i.key() + "=" + i.value());
-          ++i;
+         ++i;
         }
 
   qstring_save (fname, l.join ("\n"));
@@ -373,6 +380,10 @@ bool is_image (const QString &filename)
   for (QList <QByteArray>::iterator i = a.begin(); i != a.end(); ++i)
       {
        QString t (i->data());
+
+       if (t == "pdf") //hack for qt6
+          continue;
+
        if (filename.endsWith (t.prepend ("."), Qt::CaseInsensitive))
           return true;
       }
@@ -431,12 +442,13 @@ void CFilesList::iterate (QFileInfo &fi)
      {
       QDir d (fi.absoluteFilePath());
       QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
+
       for (int i = 0; i < lfi.count(); i++)
            iterate (lfi[i]);
      }
   else
   if (fi.isFile())
-     list.append (fi.absoluteFilePath());
+      list.append (fi.absoluteFilePath());
 }
 
 
@@ -448,6 +460,7 @@ void CFilesList::get (const QString &path)
   list.clear();
   QDir d (path);
   QFileInfoList lfi= d.entryInfoList (QDir::Dirs | QDir::Files | QDir::Readable | QDir::NoDotAndDotDot);
+
   for (int i = 0; i < lfi.count(); i++)
       iterate (lfi[i]);
 }
@@ -461,15 +474,14 @@ void CFilesList::get (const QString &path)
 #endif
 
 
-
 CFTypeChecker::CFTypeChecker()
 {
-
   ADDTEXTTYPE (".*(readme|news|changelog|todo)$");
   ADDTEXTTYPE ("^\\..*(rc)$");
   ADDTEXTTYPE ("^.*\\.(txt|conf|md|ini|bat|cfg|sbv|log|odt|docx|kwd|fb2|fb2.zip|fbz|abw|rtf|epub|sxw)$");
   ADDTEXTTYPE ("^.*\\.(cpp|c|h|hh|cxx|hpp|cc|m|mm)$");
   ADDTEXTTYPE ("^.*\\.(htm|html|xml|xhtml|ts|osm|xsl)$");
+
 #if defined(POPPLER_ENABLE)
   ADDTEXTTYPE ("^.*\\.(pdf)$");
 #endif
@@ -477,7 +489,6 @@ CFTypeChecker::CFTypeChecker()
   ADDTEXTTYPE ("^.*\\.(djvu)$");
 #endif
 
-
   ADDTEXTTYPE ("^.*\\.(awk)$");
   ADDTEXTTYPE ("^.*\\.(sh)$");
   ADDTEXTTYPE ("^.*\\.(bas|bi|vbs|vbe)$");
@@ -596,27 +607,21 @@ bool CFTypeChecker::check (const QString &fname) const
 #if QT_VERSION < 0x050000
 
   for (size_t i = 0; i < patterns.size(); ++i)
-     {
-      if (patterns[i].exactMatch(fname))
-         return true;
-     }
+      {
+       if (patterns[i].exactMatch(fname))
+          return true;
+      }
 
 #else
 
   for (size_t i = 0; i < patterns.size(); ++i)
-     {
-      QRegularExpressionMatch match = patterns[i].match(fname);
-      if (match.hasMatch())
-         return true;
-      }
+      {
+       QRegularExpressionMatch match = patterns[i].match(fname);
+       if (match.hasMatch())
+          return true;
+       }
 
 #endif
 
   return false;
 }
-
-
-/*
-GUI functions
-*/
-
